@@ -1,11 +1,11 @@
  #Pearson or polychoric correlations with confidence intervals
 
  "cor.ci" <- 
-function(x, keys = NULL, n.iter = 100, p = 0.05, overlap=FALSE, poly = FALSE, method = "pearson",plot=TRUE,...) {
-corCi(x=x, keys = keys, n.iter = n.iter, p = p, overlap=overlap, poly = poly, method = method,plot=plot,...) }
+function(x, keys = NULL, n.iter = 100, p = 0.05, overlap=FALSE, poly = FALSE, method = "pearson",plot=TRUE,minlength=5,...) {
+corCi(x=x, keys = keys, n.iter = n.iter, p = p, overlap=overlap, poly = poly, method = method,plot=plot,minlength=minlength,...) }
 
  "corCi" <- 
-function(x, keys = NULL, n.iter = 100, p = 0.05, overlap=FALSE, poly = FALSE, method = "pearson",plot=TRUE,...) {
+function(x, keys = NULL, n.iter = 100, p = 0.05, overlap=FALSE, poly = FALSE, method = "pearson",plot=TRUE,minlength=5,...) {
 
  cl <- match.call()
  n.obs <- dim(x)[1]
@@ -117,7 +117,7 @@ if(length(pvars)==ncol(x)) {tet <- polychoric(x)
       tci <- abs(means.rot)/sds.rot
       ptci <- pnorm(tci)
       ci.rot <- data.frame(lower=ci.rot.lower,low.e=low.e,upper=ci.rot.upper,up.e=up.e,p =2*(1-ptci))
-      cnR <- abbreviate(colnames(rho),minlength=5) 
+      cnR <- abbreviate(colnames(rho),minlength=minlength) 
       k <- 1
      for(i in 1:(nvar-1)) {for (j in (i+1):nvar) {
       rownames(ci.rot)[k] <- paste(cnR[i],cnR[j],sep="-")
@@ -137,12 +137,16 @@ return(results)
  #written Sept 20, 2013 
  #adapted from fa.poly
  #modified May 1, 2014 to scale by pvals
- "cor.plot.upperLowerCi" <- 
-function(R,numbers=TRUE,cuts=c(.001,.01,.05),select=NULL,main="Upper and lower confidence intervals of correlations",...) {
+ #modified August 24, 2017 to include Bonferoni corrections from cor.test
+ 
+ "cor.plot.upperLowerCi" <- "corPlotUpperLowerCi" <-
+function(R,numbers=TRUE,cuts=c(.001,.01,.05),select=NULL,main="Upper and lower confidence intervals of correlations",adjust=FALSE,...) {
 
-lower <- R$ci$lower
-upper <- R$ci$upper
-temp <- lower
+if(adjust) {lower <- R$ci.adj$lower.adj
+   upper <- R$ci.adj$upper.adj} else {
+   lower <- R$ci$lower
+upper <- R$ci$upper}
+temp <- lower 
 if(is.null(R$r)) {cn = colnames(R$rho)
          rl <- R$rho[lower.tri(R$rho)]} else {
          cn = colnames(R$r)
