@@ -183,7 +183,7 @@ function(from,to,labels=NULL,scale=1,cex=1,adj=2, both=FALSE,pos=NULL,l.cex,gap.
   		}
 }
 
-"dia.curved.arrow" <- function(from,to,labels=NULL,scale=1,both=FALSE,...) {
+"dia.curved.arrow" <- function(from,to,labels=NULL,scale=1,both=FALSE,dir=NULL,...) {
      #note that the splines seem to go from left to right no matter what!
      #first determine whether to add or subtract the radius
      
@@ -206,7 +206,12 @@ function(from,to,labels=NULL,scale=1,cex=1,adj=2, both=FALSE,pos=NULL,l.cex,gap.
      scale <- .8 * scale
       n <- 40
      if(is.null(labels)) {shift<- 0} else {shift <- 4}
-    if(abs(from[1] - to[1]) < abs(from[2] - to[2]))  { #is it primarily up and down or left to right?
+     #3 cases: dir="u", dir = "l", dir = NULL
+      if(is.null(dir)) {
+            if((abs(from[1] - to[1]) < abs(from[2] - to[2]))) {dir <- "u"} else {dir <- "l"}}
+      switch(dir,
+   # if(is.null(dir) & (abs(from[1] - to[1]) < abs(from[2] - to[2]))) 
+      u =  { #is it primarily up and down or left to right?
    		 x <- c(from[1],(from[1]+to[1])/2+scale,to[1])
    		 y <- c(from[2],(from[2]+to[2])/2,to[2])
    		sp <- spline(y,x,n)
@@ -215,7 +220,8 @@ function(from,to,labels=NULL,scale=1,cex=1,adj=2, both=FALSE,pos=NULL,l.cex,gap.
      	arrows(sp$y[3],sp$x[3],sp$y[1],sp$x[1],length = .5*abs(sp$x[2]-sp$x[1]))
      	if(both) arrows(sp$y[n-3],sp$x[n-3],sp$y[n],sp$x[n],length = .5*abs(sp$x[2]-sp$x[1]))
   		text(sp$y[n/2],sp$x[n/2],labels,...)  
-  		} else {
+  		}, 
+  	   l =  {
   		 x <- c(from[1],(from[1]+to[1])/2,to[1])
    		 y <- c(from[2],(from[2]+to[2])/2+ scale,to[2])
    		sp <- spline(x,y,n)
@@ -227,7 +233,8 @@ function(from,to,labels=NULL,scale=1,cex=1,adj=2, both=FALSE,pos=NULL,l.cex,gap.
      	   } else {if((from[1] > to[1] ) ) {arrows(sp$x[3],sp$y[3],sp$x[1],sp$y[1],length = 1*abs(sp$y[2]-sp$y[1])) } else {
      	arrows(sp$x[n-3],sp$y[n-3],sp$x[n],sp$y[n],length = 1*abs(sp$y[2]-sp$y[1]))}
   		text(sp$x[n/2],sp$y[n/2],labels,...)  }
-  		}
+  		})
+  		
 }
 
 
