@@ -9,6 +9,7 @@
           if(!is.null(fo$Phi)) {Phi <- fo$Phi} else {Phi <- NULL}
           
        fl <- fo$loadings 
+       fs <- fo$Structure
        
      } else {if (class(fo)[2] == "omega") {
          omega <- TRUE
@@ -33,7 +34,8 @@
      fe <- (fe * d)
  }
  colnames(fe) <- colnames(fl)
-if(!is.null(Phi)) {resid <- Roe - fl %*% Phi %*% t(fe)} else {resid <- fl  %*% t(fe)}
+ rownames(fe) <- colnames(Roe)
+if(!is.null(Phi)) {resid <- Roe - fl %*% Phi %*% t(fe)} else {resid <- Roe - fl  %*% t(fe)}   #fixed to actually give residual  (1/30/18)
  result <- list(loadings = fe,Phi=Phi,resid=resid,Call=cl)
  if(!omega)  {result <- list(loadings = fe,Phi=Phi,resid=resid,Call=cl)} else {result <- list(loadings = fe,oblique= feoblique,Phi=Phi,resid=resid,Call=cl)}
  class(result) <- c("psych","extension")
@@ -44,6 +46,7 @@ if(!is.null(Phi)) {resid <- Roe - fl %*% Phi %*% t(fe)} else {resid <- fl  %*% t
 
 #created December 8, 2012 to allow for extension and goodness of fits of total model
 #modified 31/5/14 to allow for omega extension as well 
+#modified 04-09/16 to pass the Structure matrix as well
 "fa.extend" <- 
 function(r,nfactors=1,ov=NULL,ev=NULL,n.obs = NA, np.obs=NULL,correct=TRUE,rotate="oblimin",SMC=TRUE,warnings=TRUE, fm="minres",alpha=.1, omega=FALSE, ...) {
  cl <- match.call()
@@ -83,7 +86,9 @@ if(omega) result$schmid$sl <- foe
               result$schmid$gloading <- fo$schmid$gloading
               result$schmid$oblique <- oblique
             }
+   if(is.null(fo$Phi)) {result$Structure <- foe } else { result$Structure <- foe %*% fo$Phi}
     result$fe=fe
+    result$resid=fe$resid
     result$Phi=fo$Phi
     result$fn="fa"
     result$Call=cl
